/**
 * @file   args.h
 * @author Jade Cheng
 * @date   September 28, 2009
 */

#ifndef __ARGS_H__
#define __ARGS_H__

#include <stdlib.h>

/** The maximum number of arguments allowed on the command line. */
#define ARGS_MAX 1024

/** Information about the arguments on the command line. */
typedef struct args_t {

        /** The number of arguments. */
        size_t count;

        /** The arguments. */
        char * values[ARGS_MAX + 1];

} args_t;

/**
 * Finds an argument starting from an index.
 *
 * @param args A pointer to the arguments.
 * @param start The starting index.
 * @param value The argument text to find.
 *
 * @return The index of the argument or -1 if the argument was not found.
 */
extern int args_find(const args_t * args, size_t start, const char * value);

/**
 * Parses command line input into an args_t structure.
 *
 * @param line The unparsed command line input.
 * @param args The result of the function.
 *
 * @return EXIT_SUCCESS or EXIT_FAILURE.
 */
extern int args_parse(char * line, args_t * args);

#endif /* __ARGS_H__*/
