/**
 * @file   pipes.h
 * @author Jade Cheng
 * @date   September 28, 2009
 */

#ifndef __PIPES_H__
#define __PIPES_H__

#include <stdlib.h>
#include "args.h"

/** The maximum number of allowed pipes at one time. */
#define PIPES_MAX 16

/** A pair of file descriptors for reading and writing. */
typedef struct pipes_fd_t {

        /** The read end of the pipe. */
        int read;

        /** The write end of the pipe. */
        int write;

} pipes_fd_t;

/**
 * A collection of data used to fork child processes.  The IO of these child
 * processes can be piped together using the file descriptors of this structure.
 */
typedef struct pipes_t {

        /** The number of pipes created. */
        size_t count;

        /** The arguments passed to each forked child process. */
        args_t children[PIPES_MAX + 1];

        /** The file descriptors for each pipe that connects the children. */
        pipes_fd_t fd[PIPES_MAX];

} pipes_t;

/**
 * Parses an arguments structure into a pipes structure.  See the pipes_t
 * structure for more information.
 *
 * @param args The arguments structure.
 * @param pipes The output of the function if it is successful.
 *
 * @return EXIT_SUCCESS or EXIT_FAILURE;
 */
extern int pipes_parse(const args_t * args, pipes_t * pipes);

#endif /* __PIPES_H__*/
